{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Modula-2.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/modula-2.xml and 'make bootstrap'.
module Skylighting.Syntax.Modula2 (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Modula-2.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmodula-2.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aModula2\NUL\NUL\NUL\NUL\NUL\NUL\NUL%\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcommon-constants\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFALSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNIL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTRUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcommon-keywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL%\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQARRAY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBEGIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXBY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCONST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDEFINITION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDIV\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXDO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTELSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQELSIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTEXIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXFOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFROM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOIMPLEMENTATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIMPORT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLOOP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMOD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMODULE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPOINTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPROCEDURE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRECORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKREPEAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRETURN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTHEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXTO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTYPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUNTIL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXVAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWHILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1common-procedures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXABS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCHR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMAX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXODD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcommon-types\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBOOLEAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCARDINAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aINTEGER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLONGREAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTREAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcommon-unsafe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aADDRESS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXADR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\riso-constants\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFALSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rINTERRUPTIBLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNIL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTRUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIUNINTERRUPTIBLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fiso-keywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL.\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQARRAY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBEGIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXBY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCONST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDEFINITION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDIV\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXDO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTELSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQELSIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTEXIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKEXCEPT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKEXPORT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFINALLY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXFOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFORWARD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFROM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOIMPLEMENTATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIMPORT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLOOP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMOD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMODULE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPACKEDSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPOINTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPROCEDURE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tQUALIFIED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRECORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXREM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKREPEAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRETRY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRETURN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTHEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXTO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTYPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUNTIL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXVAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWHILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWITH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\niso-macros\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNEW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bALLOCATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDISPOSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDEALLOCATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2iso-only-constants\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rINTERRUPTIBLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIUNINTERRUPTIBLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1iso-only-keywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKEXCEPT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFINALLY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPACKEDSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXREM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRETRY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2iso-only-libraries\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bIOConsts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIOLink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bIOResult\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLongIO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aWholeIO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRawIO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSIOResult\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSLongIO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSWholeIO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSRealIO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSRawIO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tConvTypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRealStr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bWholeStr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tWholeConv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3iso-only-procedures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCMPLX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLFLOAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXRE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOiso-only-types\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPROTECTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIiso-only-unsafe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBITSPERLOC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vBITSPERWORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLOC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKADDADR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDIFADR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMAKEADR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKROTATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSHIFT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSUBADR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOiso-procedures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXABS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCAP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCHR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCMPLX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDEC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTEXCL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFLOAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTHALT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTHIGH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXINC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTINCL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLENGTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLFLOAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMAX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXODD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXRE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTRUNC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXVAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tiso-types\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBOOLEAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBITSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCARDINAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCOMPLEX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aINTEGER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLONGCOMPLEX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLONGREAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPROC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPROTECTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTREAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\niso-unsafe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSYSTEM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBITSPERLOC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vBITSPERWORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aADDRESS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLOC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKADDADR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXADR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCAST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDIFADR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMAKEADR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKROTATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSHIFT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSUBADR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTSIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpim-constants\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFALSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNIL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTRUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpim-keywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQARRAY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBEGIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXBY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCONST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDEFINITION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDIV\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXDO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTELSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQELSIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTEXIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKEXPORT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXFOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFROM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOIMPLEMENTATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIMPORT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLOOP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMOD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMODULE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPOINTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPROCEDURE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tQUALIFIED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRECORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKREPEAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRETURN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTHEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXTO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTYPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUNTIL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXVAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWHILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWITH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npim-macros\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNEW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bALLOCATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDISPOSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDEALLOCATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2pim-only-libraries\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQInOut\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMathLib0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOpim-procedures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXABS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCAP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCHR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDEC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTEXCL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFLOAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTHALT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTHIGH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXINC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTINCL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMAX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXODD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTRUNC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXVAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpim-types\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBOOLEAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBITSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCARDINAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aINTEGER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLONGINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLONGREAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPROC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTREAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npim-unsafe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSYSTEM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aADDRESS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPROCESS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXADR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNEWPROCESS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTRANSFER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTSIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rr10-constants\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFALSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNIL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTRUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fr10-keywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQALIAS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aARGLIST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQARRAY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBEGIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBLUEPRINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXBY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCONST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCOPY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDEFINITION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDIV\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXDO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTELSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQELSIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTEXIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXFOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFROM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGENLIB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOIMPLEMENTATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIMPORT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLOOP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMOD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMODULE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNEW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKOPAQUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPOINTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPROCEDURE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTREAD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRECORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vREFERENTIAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRELEASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKREPEAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRETAIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRETURN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTHEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXTO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTYPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUNTIL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXVAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWHILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWRITE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQYIELD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nr10-macros\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTLIMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTMAX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTMIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTSIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1r10-only-keywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQALIAS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aARGLIST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBLUEPRINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCOPY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGENLIB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKOPAQUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTREAD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vREFERENTIAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRELEASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRETAIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWRITE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQYIELD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2r10-only-libraries\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPervasiveIO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bUnsafeIO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIr10-only-macros\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTLIMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTMAX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTMIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3r10-only-procedures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAPPEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCAPACITY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCOUNT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKINSERT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLOG2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPOW2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPRED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXPTR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKREMOVE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSGN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSUCC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOr10-only-types\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQOCTET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aUNICHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIr10-only-unsafe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKUNSAFE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLONGWORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bOCTETSEQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXBIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBWAND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBWNOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBWOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSETBIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSHL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSHR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOr10-procedures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXABS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAPPEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCAPACITY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCHR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCOUNT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKENTIER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKINSERT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLENGTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLOG2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMAX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXODD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPOW2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPRED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXPTR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKREMOVE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSGN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSUCC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tr10-types\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBOOLEAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCARDINAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aINTEGER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLONGCARD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLONGINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLONGREAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQOCTET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTREAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aUNICHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nr10-unsafe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCAST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKUNSAFE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBitsPerAddress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vBitsPerByte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBytesPerWord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEBytesPerLongWord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aADDRESS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBYTE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLONGWORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bOCTETSEQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXADD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXADR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXBIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBWAND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBWNOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBWOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTHALT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSETBIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSHL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSHR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNOP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nworkaround\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX???\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBlockComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBlockComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SOH(*\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBlockComment\SOH*)\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCommon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCommon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX???\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\\(\\*\\!m2pim(\\+[a-z][a-z0-9]*)?\\*\\)\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXPIM\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\\(\\*\\!m2iso(\\+[a-z][a-z0-9]*)?\\*\\)\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXISO\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\\(\\*\\!m2r10(\\+[a-z][a-z0-9]*)?\\*\\)\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXR10\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQARRAY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBEGIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXBY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCONST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDEFINITION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDIV\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXDO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTELSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQELSIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTEXIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXFOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFROM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOIMPLEMENTATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIMPORT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLOOP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMOD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMODULE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPOINTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPROCEDURE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRECORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKREPEAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRETURN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTHEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXTO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTYPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUNTIL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXVAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWHILE\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFALSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNIL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTRUE\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBOOLEAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCARDINAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aINTEGER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLONGREAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTREAL\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXABS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCHR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMAX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXODD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXORD\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aADDRESS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXADR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWORD\ESC\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKEXCEPT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFINALLY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPACKEDSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXREM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRETRY\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXISO\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQALIAS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aARGLIST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBLUEPRINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCOPY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGENLIB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKOPAQUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTREAD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vREFERENTIAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRELEASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRETAIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWRITE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQYIELD\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXR10\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rINTERRUPTIBLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIUNINTERRUPTIBLE\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXISO\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPROTECTION\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXISO\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQOCTET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aUNICHAR\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXR10\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCMPLX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLFLOAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXRE\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXISO\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAPPEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCAPACITY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCOUNT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKINSERT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLOG2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPOW2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPRED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXPTR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKREMOVE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSGN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSUCC\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXR10\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTLIMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTMAX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTMIN\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXR10\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKADDADR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBITSPERLOC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vBITSPERWORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDIFADR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLOC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMAKEADR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKROTATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSHIFT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSUBADR\ESC\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXISO\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXBIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBWAND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBWNOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBWOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLONGWORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bOCTETSEQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSETBIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSHL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSHR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKUNSAFE\ESC\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXR10\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQInOut\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMathLib0\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXPIM\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tConvTypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bIOConsts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIOLink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bIOResult\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLongIO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRawIO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRealStr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSIOResult\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSLongIO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSRawIO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSRealIO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSWholeIO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tWholeConv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aWholeIO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bWholeStr\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXISO\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPervasiveIO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bUnsafeIO\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXR10\t\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fDoubleQuoted\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSingleQuoted\SOH(*\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBlockComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fDoubleQuoted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fDoubleQuoted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXISO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXISO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL.\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQARRAY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBEGIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXBY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCONST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDEFINITION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDIV\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXDO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTELSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQELSIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKEXCEPT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTEXIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKEXPORT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFINALLY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXFOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFORWARD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFROM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOIMPLEMENTATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIMPORT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLOOP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMOD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMODULE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPACKEDSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPOINTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPROCEDURE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tQUALIFIED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRECORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXREM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKREPEAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRETRY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRETURN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTHEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXTO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTYPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUNTIL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXVAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWHILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWITH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFALSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rINTERRUPTIBLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNIL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTRUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIUNINTERRUPTIBLE\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBITSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBOOLEAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCARDINAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCOMPLEX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aINTEGER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLONGCOMPLEX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLONGREAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPROC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPROTECTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTREAL\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXABS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCAP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCHR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCMPLX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDEC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTEXCL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFLOAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTHALT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTHIGH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXINC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTINCL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLENGTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLFLOAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMAX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXODD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXRE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTRUNC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXVAL\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bALLOCATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDEALLOCATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDISPOSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNEW\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKADDADR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aADDRESS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXADR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBITSPERLOC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vBITSPERWORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCAST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDIFADR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLOC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMAKEADR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKROTATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSHIFT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSUBADR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSYSTEM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTSIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWORD\ESC\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN0[0-9A-F]*H|[0-7]+[BC]\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fDoubleQuoted\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSingleQuoted\SOH<*\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nISO-Pragma\SOH(*\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBlockComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nISO-Pragma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nISO-Pragma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH*>\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLineComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLineComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXPIM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXPIM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQARRAY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBEGIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXBY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCONST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDEFINITION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDIV\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXDO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTELSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQELSIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTEXIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKEXPORT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXFOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFROM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOIMPLEMENTATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIMPORT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLOOP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMOD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMODULE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPOINTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPROCEDURE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tQUALIFIED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRECORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKREPEAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRETURN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTHEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXTO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTYPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUNTIL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXVAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWHILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWITH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFALSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNIL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTRUE\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBITSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBOOLEAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCARDINAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aINTEGER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLONGINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLONGREAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPROC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTREAL\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXABS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCAP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCHR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDEC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTEXCL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFLOAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTHALT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTHIGH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXINC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTINCL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMAX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXODD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTRUNC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXVAL\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bALLOCATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDEALLOCATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDISPOSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNEW\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aADDRESS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXADR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNEWPROCESS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPROCESS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSYSTEM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTRANSFER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTSIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWORD\ESC\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN0[0-9A-F]*H|[0-7]+[BC]\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fDoubleQuoted\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSingleQuoted\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX(*$\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPIM-Pragma\SOH(*\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBlockComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPIM-Pragma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPIM-Pragma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH*)\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXR10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXR10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQALIAS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aARGLIST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQARRAY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBEGIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBLUEPRINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXBY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCONST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCOPY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDEFINITION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDIV\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXDO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTELSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQELSIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTEXIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXFOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFROM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGENLIB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOIMPLEMENTATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIMPORT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLOOP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMOD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMODULE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNEW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKOPAQUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPOINTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPROCEDURE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTREAD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRECORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vREFERENTIAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRELEASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKREPEAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRETAIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRETURN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTHEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXTO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTYPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUNTIL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXVAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWHILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWRITE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQYIELD\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFALSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNIL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTRUE\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBOOLEAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCARDINAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aINTEGER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLONGCARD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLONGINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLONGREAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQOCTET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTREAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aUNICHAR\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXABS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAPPEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCAPACITY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCHR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCOUNT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKENTIER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKINSERT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLENGTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLOG2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMAX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXODD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPOW2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPRED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXPTR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKREMOVE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSGN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSUCC\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTLIMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTMAX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTMIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTSIZE\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXADD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aADDRESS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXADR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXBIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBWAND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBWNOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBWOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBYTE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBitsPerAddress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vBitsPerByte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEBytesPerLongWord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBytesPerWord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCAST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTHALT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLONGWORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNOP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bOCTETSEQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSETBIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSHL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSHR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKUNSAFE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWORD\ESC\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL20b([01]+('[01]+)?)+|0[ux]([0-9A-F]+('[0-9A-F]+)?)+\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM([1-9][0-9]*('[0-9]+)*)|0\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fDoubleQuoted\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSingleQuoted\SOH<*\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nISO-Pragma\NUL!\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLineComment\SOH(*\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBlockComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSingleQuoted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSingleQuoted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSB. Kowarsch (trijezdci@github)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.mod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.def\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCommon"
